@@ -2,7 +2,7 @@
  * ====                   FRACTAL GRAPHICS GENERATOR                     ====
  * ==========================================================================
  *
- * Copyright (C) 2003-2018 by Thomas Dreibholz
+ * Copyright (C) 2003-2021 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact: dreibh@iem.uni-due.de
+ * Contact: thomas.dreibholz@gmail.com
  */
 
 #ifndef UINTCONFIGENTRY_H
@@ -34,9 +34,9 @@ class UIntConfigEntry : public ConfigEntry  {
    UIntConfigEntry(unsigned int* valuePtr, const char* name);
    ~UIntConfigEntry();
 
-   virtual QString getName() const;
-   virtual QString getValueAsString() const;
-   virtual void setValueFromString(const QString& valueString);
+   virtual QString getName() const override;
+   virtual QString getValueAsString() const override;
+   virtual void setValueFromString(const QString& valueString) override;
 
    private:
    QString       EntryName;
